Class: ThreeScaleToolbox::Commands::CopyCommand::ServiceSubcommand
- Inherits:
-
Cri::CommandRunner
- Object
- Cri::CommandRunner
- ThreeScaleToolbox::Commands::CopyCommand::ServiceSubcommand
- Includes:
- ThreeScaleToolbox::Command
- Defined in:
- lib/3scale_toolbox/commands/copy_command/service_command.rb
Class Method Summary collapse
Methods included from ThreeScaleToolbox::Command
#config, #config_file, #exit_with_message, #fetch_required_option, included, #keep_alive, #remotes, #threescale_client, #verbose, #verify_ssl
Class Method Details
.command ⇒ Object
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/3scale_toolbox/commands/copy_command/service_command.rb', line 7 def self.command Cri::Command.define do name 'service' usage 'service [opts] -s <src> -d <dst> <source-service>' summary 'copy service' description " This command makes a copy of the referenced service.\n Target service will be searched by source service system name. System name can be overriden with `--target_system_name` option.\n If a service with the selected `system_name` is not found, it will be created.\n \\n Components of the service being copied:\n \\nservice settings\n \\nproxy settings\n \\npricing rules\n \\nactivedocs\n \\nmetrics\n \\nmethods\n \\napplication plans\n \\nmapping rules\n HEREDOC\n\n option :s, :source, '3scale source instance. Url or remote name', argument: :required\n option :d, :destination, '3scale target instance. Url or remote name', argument: :required\n option :t, 'target_system_name', 'Target system name. Default to source system name', argument: :required\n flag :f, :force, 'Overwrites the mapping rules by deleting all rules from target service first'\n flag :r, 'rules-only', 'Only mapping rules are copied'\n param :source_service\n\n runner Commands::ServiceCommand::CopySubcommand\n end\nend\n" |